@@ -19,26 +19,28 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dbprovider.c,v 1.45 2014/07/20 21:27:06 plm Exp $
+ * $Id: dbprovider.c,v 1.56 2018/07/31 20:15:11 plm Exp $
  */
 
 #include "config.h"
 #include "gnubgmodule.h"
-#include "stdlib.h"
-
 #include "backgammon.h"
-#include <glib/gstdio.h>
-#include <string.h>
 #include "dbprovider.h"
 
-DBProviderType dbProviderType = (DBProviderType) 0;
+#include <stdlib.h>
+#include <glib/gstdio.h>
+#include <string.h>
+
+DBProviderType dbProviderType = (DBProviderType)INVALID_PROVIDER ;
 int storeGameStats = TRUE;
 
-#if USE_PYTHON
-PyObject *pdict;
-RowSet *ConvertPythonToRowset(PyObject * v);
+#if defined(USE_PYTHON)
+#include "pylocdefs.h"
 
-#if !USE_SQLITE
+static PyObject *pdict;
+static RowSet *ConvertPythonToRowset(PyObject * v);
+
+#if !defined(USE_SQLITE)
 static int PySQLiteConnect(const char *dbfilename, const char *user, const char *password, const char *hostname);
 #endif
 static int PyMySQLConnect(const char *dbfilename, const char *user, const char *password, const char *hostname);
@@ -46,16 +48,14 @@ static void PyDisconnect(void);
 static RowSet *PySelect(const char *str);
 static int PyUpdateCommand(const char *str);
 static void PyCommit(void);
-#if !defined(WIN32)
 static int PyPostgreConnect(const char *dbfilename, const char *user, const char *password, const char *hostname);
 static GList *PyPostgreGetDatabaseList(const char *user, const char *password, const char *hostname);
 static int PyPostgreDeleteDatabase(const char *dbfilename, const char *user, const char *password,
                                    const char *hostname);
-#endif
 static GList *PyMySQLGetDatabaseList(const char *user, const char *password, const char *hostname);
 static int PyMySQLDeleteDatabase(const char *dbfilename, const char *user, const char *password, const char *hostname);
 #endif
-#if USE_SQLITE
+#if defined(USE_SQLITE)
 static int SQLiteConnect(const char *dbfilename, const char *user, const char *password, const char *hostname);
 static void SQLiteDisconnect(void);
 static RowSet *SQLiteSelect(const char *str);
@@ -67,13 +67,13 @@ static void SQLiteCommit(void);
 static int SQLiteDeleteDatabase(const char *dbfilename, const char *user, const char *password, const char *hostname);
 static GList *SQLiteGetDatabaseList(const char *user, const char *password, const char *hostname);
 static DBProvider providers[NUM_PROVIDERS] = {
-#if USE_SQLITE
+#if defined(USE_SQLITE)
     {SQLiteConnect, SQLiteDisconnect, SQLiteSelect, SQLiteUpdateCommand, SQLiteCommit, SQLiteGetDatabaseList,
      SQLiteDeleteDatabase,
      "SQLite", "SQLite", "Direct SQLite3 connection", FALSE, TRUE, "gnubg", "", "", ""},
 #endif
-#if USE_PYTHON
-#if !USE_SQLITE
+#if defined(USE_PYTHON)
+#if !defined(USE_SQLITE)
     {PySQLiteConnect, PyDisconnect, PySelect, PyUpdateCommand, PyCommit, SQLiteGetDatabaseList, SQLiteDeleteDatabase,
      "SQLite (Python)", "PythonSQLite", "SQLite3 connection included in latest Python version", FALSE, TRUE, "gnubg",
      "", "", ""},
@@ -81,20 +81,18 @@ static DBProvider providers[NUM_PROVIDERS] = {
     {PyMySQLConnect, PyDisconnect, PySelect, PyUpdateCommand, PyCommit, PyMySQLGetDatabaseList, PyMySQLDeleteDatabase,
      "MySQL (Python)", "PythonMySQL", "MySQL connection via MySQLdb Python module", TRUE, TRUE, "gnubg", "", "",
      "localhost:3306"},
-#if !defined(WIN32)
     {PyPostgreConnect, PyDisconnect, PySelect, PyUpdateCommand, PyCommit, PyPostgreGetDatabaseList,
      PyPostgreDeleteDatabase,
-     "Postgres (Python)", "PythonPostgre", "PostgreSQL connection via PyGreSQL Python module", TRUE, TRUE, "gnubg", "",
+     "PostgreSQL (Python)", "PythonPostgre", "PostgreSQL connection via PyGreSQL Python module", TRUE, TRUE, "gnubg", "",
      "", "localhost:5432"},
 #endif
-#endif
 };
 
 #else
 DBProvider providers[1] = { {0, 0, 0, 0, 0, 0, 0, "No Providers", "No Providers", "No Providers", 0, 0, 0, 0, 0, 0} };
 #endif
 
-#if USE_PYTHON || USE_SQLITE
+#if defined(USE_PYTHON) || defined(USE_SQLITE)
 static RowSet *
 MallocRowset(size_t rows, size_t cols)
 {
@@ -136,20 +134,24 @@ SetRowsetData( /*lint -e{818} */ RowSet * rs, size_t row, size_t col, const char
 extern void
 FreeRowset(RowSet * pRow)
 {
-    unsigned int i, j;
-    free(pRow->widths);
+    if (pRow != NULL) {
+        free(pRow->widths);
 
-    for (i = 0; i < pRow->rows; i++) {
-        for (j = 0; j < pRow->cols; j++) {
-            free(pRow->data[i][j]);
+        if (pRow->data != NULL) {
+            unsigned int i, j;
+
+            for (i = 0; i < pRow->rows; i++) {
+                for (j = 0; j < pRow->cols; j++) {
+                    free(pRow->data[i][j]);
+                }
+            free(pRow->data[i]);
+            }
         }
-        free(pRow->data[i]);
-    }
-    free(pRow->data);
 
-    pRow->cols = pRow->rows = 0;
-    pRow->data = NULL;
-    pRow->widths = NULL;
+        free(pRow->data);
+    }   
+
+    free(pRow);
 }
 
 int
@@ -161,8 +163,10 @@ RunQueryValue(const DBProvider * pdb, const char *query)
         int id = (int)strtol(rs->data[1][0], NULL, 0);
         FreeRowset(rs);
         return id;
-    } else
+    } else {
+        FreeRowset(rs);
         return -1;
+    }
 }
 
 extern RowSet *
@@ -240,6 +244,11 @@ RelationalSaveSettings(FILE * pf)
         fprintf(pf, "relational setup dbtype=%s\n", providers[dbProviderType].shortname);
     for (i = 0; i < NUM_PROVIDERS; i++) {
         DBProvider *pdb = GetDBProvider((DBProviderType) i);
+
+        g_assert(pdb != NULL);
+        if (pdb == NULL)
+            return;
+
         fprintf(pf, "relational setup %s-database=%s\n", providers[i].shortname, pdb->database);
         fprintf(pf, "relational setup %s-username=%s\n", providers[i].shortname, pdb->username);
         fprintf(pf, "relational setup %s-password=%s\n", providers[i].shortname, pdb->password);
@@ -250,7 +259,7 @@ RelationalSaveSettings(FILE * pf)
 extern DBProvider *
 GetDBProvider(DBProviderType dbType)
 {
-#if USE_PYTHON
+#if defined(USE_PYTHON)
     static int setup = FALSE;
     if (!setup) {
         if (LoadPythonFile("database.py", FALSE) == 0) {
@@ -278,7 +287,7 @@ GetDBProvider(DBProviderType dbType)
 #endif
 }
 
-#if USE_PYTHON
+#if defined(USE_PYTHON)
 int
 PyMySQLConnect(const char *dbfilename, const char *user, const char *password, const char *hostname)
 {
@@ -294,13 +303,12 @@ PyMySQLConnect(const char *dbfilename, const char *user, const char *password, c
     if (ret == NULL || !PyInt_Check(ret) || (iret = PyInt_AsLong(ret)) < 0) {
         PyErr_Print();
         return -1;
-    } else if (iret == 0L) {     /* New database - populate */
+    } else if (iret == 0L) {    /* New database - populate */
         return 0;
     }
     return 1;
 }
 
-#if !defined(WIN32)
 int
 PyPostgreConnect(const char *dbfilename, const char *user, const char *password, const char *hostname)
 {
@@ -315,14 +323,13 @@ PyPostgreConnect(const char *dbfilename, const char *user, const char *password,
     if (ret == NULL || !PyInt_Check(ret) || (iret = PyInt_AsLong(ret)) < 0) {
         PyErr_Print();
         return -1;
-    } else if (iret == 0L) {     /* New database - populate */
+    } else if (iret == 0L) {    /* New database - populate */
         return 0;
     }
     return 1;
 }
-#endif
 
-#if !USE_SQLITE
+#if !defined(USE_SQLITE)
 static int
 PySQLiteConnect(const char *dbfilename, const char *UNUSED(user), const char *UNUSED(password),
                 const char *UNUSED(hostname))
@@ -408,7 +415,7 @@ PyCommit(void)
         PyErr_Print();
 }
 
-RowSet *
+static RowSet *
 ConvertPythonToRowset(PyObject * v)
 {
     RowSet *pRow;
@@ -455,12 +462,12 @@ ConvertPythonToRowset(PyObject * v)
                     continue;
                 }
                 if (PyUnicode_Check(e2))
-                    strcpy(buf, PyString_AsString(PyUnicode_AsUTF8String(e2)));
-                else if (PyString_Check(e2))
-                    strcpy(buf, PyString_AsString(e2));
+                    strcpy(buf, PyBytes_AsString(PyUnicode_AsUTF8String(e2)));
+                else if (PyBytes_Check(e2))
+                    strcpy(buf, PyBytes_AsString(e2));
                 else if (PyInt_Check(e2) || PyLong_Check(e2)
                          || !StrCaseCmp(e2->ob_type->tp_name, "Decimal"))       /* Not sure how to check for decimal type directly */
-                    sprintf(buf, "%d", (int) PyInt_AsLong(e2));
+                    sprintf(buf, "%ld", PyInt_AsLong(e2));
                 else if (PyFloat_Check(e2))
                     sprintf(buf, "%.4f", PyFloat_AsDouble(e2));
                 else if (e2 == Py_None)
@@ -506,7 +513,6 @@ PyMySQLGetDatabaseList(const char *user, const char *password, const char *hostn
     }
 }
 
-#if !defined(WIN32)
 GList *
 PyPostgreGetDatabaseList(const char *user, const char *password, const char *hostname)
 {
@@ -528,7 +534,6 @@ PyPostgreGetDatabaseList(const char *user, const char *password, const char *hos
         return NULL;
     }
 }
-#endif
 
 int
 PyMySQLDeleteDatabase(const char *dbfilename, const char *user, const char *password, const char *hostname)
@@ -544,7 +549,6 @@ PyMySQLDeleteDatabase(const char *dbfilename, const char *user, const char *pass
     return ret;
 }
 
-#if !defined(WIN32)
 int
 PyPostgreDeleteDatabase(const char *dbfilename, const char *user, const char *password, const char *hostname)
 {
@@ -559,11 +563,10 @@ PyPostgreDeleteDatabase(const char *dbfilename, const char *user, const char *pa
     g_free(buf);
     return ret;
 }
-#endif
 
 #endif
 
-#if USE_SQLITE
+#if defined(USE_SQLITE)
 
 #include <sqlite3.h>
 
@@ -601,7 +604,6 @@ SQLiteDisconnect(void)
 RowSet *
 SQLiteSelect(const char *str)
 {
-    size_t i, row;
     int ret;
     char *buf = g_strdup_printf("Select %s;", str);
     RowSet *rs = NULL;
@@ -610,8 +612,10 @@ SQLiteSelect(const char *str)
     ret = sqlite3_prepare(connection, buf, -1, &pStmt, NULL);
     g_free(buf);
     if (ret == SQLITE_OK) {
+        size_t i, row;
         size_t numCols = (size_t) sqlite3_column_count(pStmt);
         size_t numRows = 0;
+
         while ((ret = sqlite3_step(pStmt)) == SQLITE_ROW)
             numRows++;
         if (sqlite3_reset(pStmt) != SQLITE_OK)
@@ -689,7 +693,8 @@ SQLiteDeleteDatabase(const char *dbfilename, const char *UNUSED(user), const cha
     /* Delete database file */
     ret = g_unlink(filename);
 
-    g_free(name), g_free(filename);
+    g_free(filename);
+    g_free(name);
     return (ret == 0);
 }
 #endif
