@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: matchequity.c,v 1.94 2014/02/12 23:06:19 plm Exp $
+ * $Id: matchequity.c,v 1.99 2016/11/23 20:55:13 plm Exp $
  */
 
 #include "config.h"
@@ -398,7 +398,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
      *
      * Output:
      * - arCP : cash points with live cube
-     * These points are necesary for the linear
+     * These points are necessary for the linear
      * interpolation used in cubeless -> cubeful equity 
      * transformation.
      */
@@ -430,7 +430,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
 
         /* arOutput evaluated for player 0 */
 
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             arG[0] = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             arBG[0] = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -438,7 +438,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
             arBG[0] = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             arG[1] = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             arBG[1] = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -450,7 +450,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
 
         /* arOutput evaluated for player 1 */
 
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             arG[1] = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             arBG[1] = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -458,7 +458,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
             arBG[1] = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             arG[0] = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             arBG[0] = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -478,7 +478,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
         nDead *= 2;
     }
 
-    for (nCubeValue = nDead, n = nMax; nCubeValue >= nCube; nCubeValue >>= 1, n--) {
+    for (nCubeValue = nDead, n = nMax; n >= 0; nCubeValue >>= 1, n--) {
 
         /* Calculate dead and live cube cash points.
          * See notes by me (Joern Thyssen) available from the
@@ -579,12 +579,12 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
 
         float rW, rL;
 
-        if (arOutput[0] > 0.0)
+        if (arOutput[0] > 0.0f)
             rW = 1.0f + (arOutput[1] + arOutput[2]) / arOutput[0];
         else
             rW = 1.0f;
 
-        if (arOutput[0] < 1.0)
+        if (arOutput[0] < 1.0f)
             rL = 1.0f + (arOutput[3] + arOutput[4]) / (1.0f - arOutput[0]);
         else
             rL = 1.0f;
@@ -617,7 +617,7 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
         float rRisk, rGain;
 
         /* FIXME: avoid division by zero */
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             rG1 = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             rBG1 = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -625,7 +625,7 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
             rBG1 = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             rG2 = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             rBG2 = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -1088,7 +1088,7 @@ readMET(metdata * met, const char *filename)
     parser->i = 0;
     parser->j = 0;
 
-    if (!(context = g_markup_parse_context_new(&markup_parser, 0, parser, met_parser_destroy))) {
+    if (!(context = g_markup_parse_context_new(&markup_parser, (GMarkupParseFlags) 0, parser, met_parser_destroy))) {
         g_warning("Can't create XML parser\n");
         g_free(parser);
         return -1;
@@ -1380,7 +1380,7 @@ static void
 met_parser_error(GMarkupParseContext * UNUSED(context), GError * UNUSED(error), gpointer user_data)
 {
     MatchEquityParser *parser = (MatchEquityParser *) user_data;
-    g_warning("An error occured while parsing file: %s\n", parser->filename);
+    g_warning("An error occurred while parsing file: %s\n", parser->filename);
 }
 
 /*
@@ -1459,23 +1459,18 @@ getGammonPrice(float arGammonPrice[4],
         arGammonPrice[3] = (rCenter - rLoseBG) / (rWin - rCenter) - (arGammonPrice[1] + 1.0f);
 
     } else
-        arGammonPrice[0] = arGammonPrice[1] = arGammonPrice[2] = arGammonPrice[3] = 0.0;
+        arGammonPrice[0] = arGammonPrice[1] = arGammonPrice[2] = arGammonPrice[3] = 0.0f;
 
 
     /* Correct numerical problems */
-    if (arGammonPrice[0] <= 0)
-        arGammonPrice[0] = 0.0;
-    if (arGammonPrice[1] <= 0)
-        arGammonPrice[1] = 0.0;
-    if (arGammonPrice[2] <= 0)
-        arGammonPrice[2] = 0.0;
-    if (arGammonPrice[3] <= 0)
-        arGammonPrice[3] = 0.0;
-
-    g_assert(arGammonPrice[0] >= 0);
-    g_assert(arGammonPrice[1] >= 0);
-    g_assert(arGammonPrice[2] >= 0);
-    g_assert(arGammonPrice[3] >= 0);
+    if (arGammonPrice[0] < 0.0f)
+        arGammonPrice[0] = 0.0f;
+    if (arGammonPrice[1] < 0.0f)
+        arGammonPrice[1] = 0.0f;
+    if (arGammonPrice[2] < 0.0f)
+        arGammonPrice[2] = 0.0f;
+    if (arGammonPrice[3] < 0.0f)
+        arGammonPrice[3] = 0.0f;
 
 }
 
@@ -1653,9 +1648,6 @@ getME(const int nScore0, const int nScore1, const int nMatchTo,
         /* non-post-Crawford games */
         return (fPlayer) ? 1.0f - aafMET[n0][n1] : aafMET[n0][n1];
 
-    g_assert_not_reached();
-    return 0.0f;
-
 }
 
 
@@ -1695,9 +1687,6 @@ getMEAtScore(const int nScore0, const int nScore1, const int nMatchTo,
         /* non-post-Crawford games */
         return (fPlayer) ? 1.0f - aafMET[n0][n1] : aafMET[n0][n1];
 
-    g_assert_not_reached();
-    return 0.0f;
-
 }
 
 
